
# Type: occurs in


holds between a process and a material entity or site within which the process occurs

URI: [biolink:occurs_in](https://w3id.org/biolink/vocab/occurs_in)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | BFO:0000066 |
|  | | SEMMEDDB:OCCURS_IN |
|  | | SEMMEDDB:PROCESS_OF |
| **In Subsets:** | | translator_minimal |

